@@ -15,7 +15,11 @@ lazy_static::lazy_static! {
 }
 
 pub fn show() {
-    TERM_STATUS.show();
+    // Only enable it if it's a TTY terminal, otherwise output
+    // can get super messy.
+    if crossterm::tty::IsTty::is_tty(&std::io::stderr()) {
+        TERM_STATUS.show();
+    }
 }
 
 pub fn hide() {
@@ -118,6 +122,7 @@ impl TermStatusInternal {
 
     fn print(&mut self, stdio: &mut impl Write) -> Result<()> {
         let rows = self.make_status_rows()?;
+
         let height = rows.len();
 
         if let (0, 0) = (height, self.current_height) {
@@ -181,6 +186,15 @@ impl TermStatusInternal {
             }
         }
 
+        let (_, term_height) = crossterm::terminal::size().unwrap_or((50, 50));
+        let max_height = term_height as usize - 2;
+
+        if rows.len() > max_height {
+            let trimmed = rows.len() - max_height;
+            rows = rows.into_iter().take(max_height).collect();
+            rows.push(format!(".......{} more tasks.......", trimmed))
+        }
+
         Ok(rows)
     }
 
